==> karate-core-0.9.5-sources.jar: com/intuit/karate/shell/StringLogAppender.java <==
/*
 * The MIT License
 *
 * Copyright 2019 Intuit Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.intuit.karate.shell;

import com.intuit.karate.LogAppender;

/**
 *
 * @author pthomas3
 */
public class StringLogAppender implements LogAppender {
    
    private final StringBuilder sb = new StringBuilder();
    
    private final boolean useLineFeed;
    
    public StringLogAppender(boolean useLineFeed) {
        this.useLineFeed = useLineFeed;
    }

    @Override
    public String collect() {
        String temp = sb.toString();
        sb.setLength(0);
        return temp;
    }

    @Override
    public void append(String text) {
        sb.append(text);
        if (useLineFeed) {
            sb.append('\n');
        }
    }

    @Override
    public void close() {
        
    }        
    
}

==> karate-core-1.3.0-sources.jar: com/intuit/karate/shell/StringLogAppender.java <==
/*
 * The MIT License
 *
 * Copyright 2019 Intuit Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.intuit.karate.shell;

import com.intuit.karate.LogAppender;

/**
 *
 * @author pthomas3
 */
public class StringLogAppender implements LogAppender {
    
    private final StringBuilder sb = new StringBuilder();
    
    private final boolean useLineFeed;
    
    public StringLogAppender(boolean useLineFeed) {
        this.useLineFeed = useLineFeed;
    }
    
    @Override
    public String getBuffer() {
        return sb.toString();
    }    
    
    @Override
    public String collect() {
        String temp = sb.toString();
        sb.setLength(0);
        return temp;
    }
    
    @Override
    public void append(String text) {
        sb.append(text);
        if (useLineFeed) {
            sb.append('\n');
        }
    }
    
    @Override
    public void close() {
        // don't dispose of buffer it can be collected later
    }    
    
}
